import React, {
  useState,
  useCallback,
  useEffect,
} from 'react';
import ReactDOM from 'react-dom';
import d3, {
  max,
  interpolateYlGn,
  scaleSequential,
} from 'd3';
import { useUsaMap } from './useUsaMap';
import { Marks } from './Marks';
import { useData } from './useData';

const width = 960;
const height = 600;

const App = () => {
  const usaMap = useUsaMap();
  const data = useData();

  if (!usaMap || !data) {
    return <pre>Loading...</pre>;
  }

  const fipsToEducation = new Map();
  data.forEach((d) => {
    fipsToEducation.set(d.fips, d.bachelorsOrHigher);
  });

  const colorValue = (d) => d.bachelorsOrHigher;

  const colorScale = scaleSequential(
    interpolateYlGn
  ).domain([0, max(data, colorValue)]);

  return (
    <svg width={width} height={height}>
      <Marks
        usaMap={usaMap}
        fipsToEducation={fipsToEducation}
        colorValue={colorValue}
        colorScale={colorScale}
      />
    </svg>
  );
};

const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
